@@ -48,7 +48,7 @@ class Calculation:
         name: name of calculation
         flow_system: flow_system which should be calculated
         folder: folder where results should be saved. If None, then the current working directory is used.
-        normalize_weights: Whether to automatically normalize the weights (periods and scenarios) to sum up to 1 when solving.
+        normalize_weights: Whether to automatically normalize the weights of scenarios to sum up to 1 when solving.
         active_timesteps: Deprecated. Use FlowSystem.sel(time=...) or FlowSystem.isel(time=...) instead.
     """
 
@@ -98,8 +98,6 @@ class Calculation:
             raise NotADirectoryError(f'Path {self.folder} exists and is not a directory.')
         self.folder.mkdir(parents=False, exist_ok=True)
 
-        self._modeled = False
-
     @property
     def main_results(self) -> dict[str, int | float | dict]:
         from flixopt.features import InvestmentModel
@@ -184,7 +182,7 @@ class FullCalculation(Calculation):
         name: name of calculation
         flow_system: flow_system which should be calculated
         folder: folder where results should be saved. If None, then the current working directory is used.
-        normalize_weights: Whether to automatically normalize the weights (periods and scenarios) to sum up to 1 when solving.
+        normalize_weights: Whether to automatically normalize the weights of scenarios to sum up to 1 when solving.
         active_timesteps: Deprecated. Use FlowSystem.sel(time=...) or FlowSystem.isel(time=...) instead.
     """
 
@@ -228,6 +226,11 @@ class FullCalculation(Calculation):
     def solve(
         self, solver: _Solver, log_file: pathlib.Path | None = None, log_main_results: bool | None = None
     ) -> FullCalculation:
+        # Auto-call do_modeling() if not already done
+        if not self.modeled:
+            logger.info('Model not yet created. Calling do_modeling() automatically.')
+            self.do_modeling()
+
         t_start = timeit.default_timer()
 
         self.model.solve(
